@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "weblio" "0.4.1"
+(define-package "weblio" "20250928.1117"
   "Look up Japanese words on Weblio.jp."
   '((request "0.3.3")
     (emacs   "25.1"))
